@@ -17,7 +17,7 @@ size_n.three_way_mixed_cxbina.model_1_bxc <-  function(alpha, beta, delta, a, b,
 	{
 		lambda <- 0.25*a*b*c*n*delta*delta
 	}
-	beta.calculated <- beta(alpha, dfn, dfd, lambda)
+	beta.calculated <- Beta(alpha, dfn, dfd, lambda)
 	if (is.nan(beta.calculated) || beta.calculated < beta )
 	{
    warning(paste("Given parameter will result in too high power.",
